summaryrefslogtreecommitdiffstats
path: root/src/mesa/program/prog_print.c
diff options
context:
space:
mode:
authorTimothy Arceri <[email protected]>2016-10-20 14:24:03 +1100
committerTimothy Arceri <[email protected]>2016-10-26 14:29:36 +1100
commite81aaeba37f5419323d8f88bc10943c77e25ed14 (patch)
tree3dc9c65fd0984128fb559aa71ed4ae4c7493995e /src/mesa/program/prog_print.c
parentdfcbdba47119de6c1d81a869f8625bcc3d7560a2 (diff)
r200/i915/st/mesa/compiler: use common inputs read field
And set set inputs_read directly in shader_info. To avoid regressions between changes this change is a squashed version of the following patches. st/mesa changes where: Reviewed-by: Marek Olšák <[email protected]> Reviewed-by: Jason Ekstrand <[email protected]>
Diffstat (limited to 'src/mesa/program/prog_print.c')
-rw-r--r--src/mesa/program/prog_print.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mesa/program/prog_print.c b/src/mesa/program/prog_print.c
index 7a7d2745460..19d578579ee 100644
--- a/src/mesa/program/prog_print.c
+++ b/src/mesa/program/prog_print.c
@@ -208,7 +208,7 @@ arb_input_attrib_string(GLuint index, GLenum progType)
/**
* Print a vertex program's InputsRead field in human-readable format.
* For debugging.
*/
void
@@ -226,7 +226,7 @@ _mesa_print_vp_inputs(GLbitfield inputs)
/**
* Print a fragment program's InputsRead field in human-readable format.
* For debugging.
*/
void
@@ -872,7 +872,7 @@ _mesa_fprint_program_parameters(FILE *f,
GLuint i;
fprintf(f, "InputsRead: %" PRIx64 " (0b%s)\n",
- (uint64_t) prog->InputsRead, binary(prog->InputsRead));
+ (uint64_t) prog->info.inputs_read, binary(prog->info.inputs_read));
fprintf(f, "OutputsWritten: %" PRIx64 " (0b%s)\n",
(uint64_t) prog->OutputsWritten, binary(prog->OutputsWritten));
fprintf(f, "NumInstructions=%d\n", prog->NumInstructions);
@@ -208,7 +208,7 @@ arb_input_attrib_string(GLuint index, GLenum progType)
/**
- * Print a vertex program's InputsRead field in human-readable format.
+ * Print a vertex program's inputs_read field in human-readable format.
* For debugging.
*/
@@ -226,7 +226,7 @@ _mesa_print_vp_inputs(GLbitfield inputs)
/**
- * Print a fragment program's InputsRead field in human-readable format.
+ * Print a fragment program's inputs_read field in human-readable format.
* For debugging.
*/